@@ -21,7 +21,7 @@
 """A Python module to parse, validate and reformat standard numbers
 and codes in different formats.
 
-Currently this module supports the following formats:
+Currently this package supports the following formats:
 
  * ISBN (International Standard Book Number)
  * ISSN (International Standard Serial Number)
@@ -33,6 +33,7 @@ Currently this module supports the following formats:
    number)
  * SSN (U.S. Social Security Number)
  * IMEI (International Mobile Equipment Identity)
+ * IMSI (International Mobile Subscriber Identity)
  * MEID (Mobile Equipment Identifier)
  * GRid (Global Release Identifier)
  * IBAN (International Bank Account Number)
@@ -46,3 +47,6 @@ Furthermore a number of generic check digit algorithms are available:
  * some algorithms described in ISO/IEC 7064: Mod 11, 2, Mod 37, 2,
    Mod 97, 10, Mod 11, 10 and Mod 37, 36
 """
+
+# the version number of the library
+__version__ = '0.6'
