@@ -37,6 +37,8 @@ False
 'ISBN13'
 >>> to_isbn13('1-85798-218-5')
 '978-1-85798-218-3'
+>>> to_isbn10('978-1-85798-218-3')
+'1-85798-218-5'
 """
 
 from stdnum import ean
@@ -47,19 +49,22 @@ def compact(number, convert=False):
     of any valid ISBN separators and removes surrounding whitespace. If the
     covert parameter is True the number is also converted to ISBN-13
     format."""
-    number = number.replace(' ','').replace('-','').strip().upper()
+    number = number.replace(' ', '').replace('-', '').strip().upper()
     if len(number) == 9:
         number = '0' + number
     if convert:
         return to_isbn13(number)
     return number
 
+
 def _calc_isbn10_check_digit(number):
     """Calculate the ISBN check digit for 10-digit numbers. The number passed
     should not have the check bit included."""
-    check = sum( (i + 1) * int(n) for i, n in enumerate(number) ) % 11
+    check = sum((i + 1) * int(n)
+                for i, n in enumerate(number)) % 11
     return 'X' if check == 10 else str(check)
 
+
 def isbn_type(number):
     """Check the passed number and returns 'ISBN13', 'ISBN10' or None (for
     invalid) for checking the type of number passed."""
@@ -82,6 +87,7 @@ def isbn_type(number):
     else:
         return None
 
+
 def is_valid(number):
     """Checks to see if the number provided is a valid ISBN (either a legacy
     10-digit one or a 13-digit one). This checks the length and the check
@@ -89,12 +95,13 @@ def is_valid(number):
     for that)."""
     return isbn_type(number) is not None
 
+
 def to_isbn13(number):
     """Convert the number to ISBN-13 format."""
     number = number.strip()
     min_number = compact(number)
     if len(min_number) == 13:
-        return number # nothing to do, already ISBN-13
+        return number  # nothing to do, already ISBN-13
     # put new check digit in place
     number = number[:-1] + ean.calc_check_digit('978' + min_number[:-1])
     # add prefix
@@ -105,6 +112,29 @@ def to_isbn13(number):
     else:
         return '978' + number
 
+
+def to_isbn10(number):
+    """Convert the number to ISBN-13 format."""
+    number = number.strip()
+    min_number = compact(number)
+    if len(min_number) == 10:
+        return number  # nothing to do, already ISBN-13
+    elif isbn_type(min_number) != 'ISBN13':
+        raise ValueError('Not a valid ISBN13.')
+    elif not number.startswith('978'):
+        raise ValueError('Does not use 978 Bookland prefix.')
+    # strip EAN prefix
+    number = number[3:-1].strip().strip('-')
+    digit = _calc_isbn10_check_digit(min_number[3:-1])
+    # append the new check digit
+    if ' ' in number:
+        return number + ' ' + digit
+    elif '-' in number:
+        return number + '-' + digit
+    else:
+        return number + digit
+
+
 def split(number, convert=False):
     """Split the specified ISBN into an EAN.UCC prefix, a group prefix, a
     registrant, an item number and a check-digit. If the number is in ISBN-10
@@ -114,19 +144,19 @@ def split(number, convert=False):
     # clean up number
     number = compact(number, convert)
     # get Bookland prefix if any
+    delprefix = False
     if len(number) == 10:
-        oprefix = ''
-        prefix = '978'
-    else:
-        oprefix = prefix = number[:3]
-        number = number[3:]
+        number = '978' + number
+        delprefix = True
     # split the number
-    result = numdb.get('isbn').split(prefix+number[:-1])[1:]
-    itemnr = result.pop()
+    result = numdb.get('isbn').split(number[:-1])
+    itemnr = result.pop() if result else ''
+    prefix = result.pop(0) if result else ''
     group = result.pop(0) if result else ''
     publisher = result.pop(0) if result else ''
     # return results
-    return ( oprefix, group, publisher, itemnr, number[-1] )
+    return ('' if delprefix else prefix, group, publisher, itemnr, number[-1])
+
 
 def format(number, separator='-', convert=False):
     """Reformat the passed number to the standard format with the EAN.UCC
