@@ -24,8 +24,8 @@ module handles both numbers in the 10-digit 13-digit format.
 True
 >>> is_valid('9790060115615')
 True
->>> is_valid(' M-2306-7118-7')
-True
+>>> ismn_type(' M-2306-7118-7')
+'ISMN10'
 >>> is_valid('9790060115614') # incorrect check digit
 False
 >>> compact('  979-0-3452-4680-5')
@@ -44,31 +44,39 @@ from stdnum import ean
 def compact(number):
     """Convert the ISMN to the minimal representation. This strips the number
     of any valid ISMN separators and removes surrounding whitespace."""
-    number = number.replace(' ','').replace('-','').replace('.','').strip().upper()
-    return number
+    number = number.replace(' ', '').replace('-', '').replace('.', '')
+    return number.strip().upper()
+
+
+def ismn_type(number):
+    """Check the type of ISMN number passed and return 'ISMN13', 'ISMN10' or None (for
+    invalid)."""
+    try:
+        number = compact(number)
+    except:
+        return None
+    if len(number) == 10 and number[0] == 'M' and number[1:].isdigit():
+        if ean.calc_check_digit('9790' + number[1:-1]) == number[-1]:
+            return 'ISMN10'
+    elif len(number) == 13 and number.isdigit():
+        if ean.calc_check_digit(number[:-1]) == number[-1]:
+            return 'ISMN13'
+    return None
+
 
 def is_valid(number):
     """Checks to see if the number provided is a valid ISMN (either a legacy
     10-digit one or a 13-digit one). This checks the length and the check
-    bit but does not check if the publisher is valid."""
-    try:
-        number = compact(number)
-    except:
-        return False
-    if len(number) == 10 and number[0] == 'M' and number[1:].isdigit():
-        if ean.calc_check_digit('9790' + number[1:-1]) == number[-1]:
-            return True
-    elif len(number) == 13 and number.isdigit():
-        if ean.calc_check_digit(number[:-1]) == number[-1]:
-            return True
-    return False
+    bit but does not check if the publisher is known."""
+    return ismn_type(number) is not None
+
 
 def to_ismn13(number):
-    """Convert the number to ISMN13 format."""
+    """Convert the number to ISMN13 (EAN) format."""
     number = number.strip()
     min_number = compact(number)
     if len(min_number) == 13:
-        return number # nothing to do, already 13 digit format
+        return number  # nothing to do, already 13 digit format
     # add prefix and strip the M
     if ' ' in number:
         return '979 0' + number[1:]
@@ -77,9 +85,12 @@ def to_ismn13(number):
     else:
         return '9790' + number[1:]
 
+
 # these are the ranges allocated to publisher codes
-_ranges = ( (3, '000', '099'), (4, '1000', '3999'), (5, '40000', '69999'),
-            (6, '700000', '899999'), (7, '9000000', '9999999') )
+_ranges = (
+    (3, '000', '099'), (4, '1000', '3999'), (5, '40000', '69999'),
+    (6, '700000', '899999'), (7, '9000000', '9999999'))
+
 
 def split(number):
     """Split the specified ISMN into a bookland prefix (979), an ISMN
@@ -89,8 +100,10 @@ def split(number):
     number = to_ismn13(compact(number))
     # rind the correct range and split the number
     for length, low, high in _ranges:
-        if low <= number[4:4+length] <= high:
-            return number[:3], number[3], number[4:4+length], number[4+length:-1], number[-1]
+        if low <= number[4:4 + length] <= high:
+            return (number[:3], number[3], number[4:4 + length],
+                    number[4 + length:-1], number[-1])
+
 
 def format(number, separator='-'):
     """Reformat the passed number to the standard format with the
