@@ -1,6 +1,6 @@
 # meid.py - functions for handling Mobile Equipment Identifiers (MEIDs)
 #
-# Copyright (C) 2010 Arthur de Jong
+# Copyright (C) 2010, 2011 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -32,12 +32,14 @@ True
 'AF 01 23 45 0A BC DE C'
 """
 
-_hex_alphabet='0123456789ABCDEF'
+_hex_alphabet = '0123456789ABCDEF'
+
 
 def _cleanup(number):
     """Remove any grouping information from the number and removes surrounding
     whitespace."""
-    return str(number).replace(' ','').replace('-','').strip().upper()
+    return str(number).replace(' ', '').replace('-', '').strip().upper()
+
 
 def _ishex(number):
     for x in number:
@@ -45,23 +47,25 @@ def _ishex(number):
             return False
     return True
 
+
 def _parse(number):
     number = _cleanup(number)
     if len(number) == 14 and _ishex(number):
         # 14-digit hex representation
-        return ( number, '' )
+        return number, ''
     elif len(number) == 15 and _ishex(number):
         # 14-digit hex representation with check digit
-        return ( number[0:14], number[14] )
+        return number[0:14], number[14]
     elif len(number) == 18 and number.isdigit():
         # 18-digit decimal representation
-        return ( number, '' )
+        return number, ''
     elif len(number) == 19 and number.isdigit():
         # 18-digit decimal representation witch check digit
-        return ( number[0:18], number[18] )
+        return number[0:18], number[18]
     else:
         return None
 
+
 def _calc_check_digit(number):
     # both the 18-digit decimal format and the 14-digit hex format
     # containing only decimal digits should use the decimal Luhn check
@@ -71,6 +75,7 @@ def _calc_check_digit(number):
     else:
         return luhn.calc_check_digit(number, alphabet=_hex_alphabet)
 
+
 def compact(number, strip_check_digit=True):
     """Convert the MEID number to the minimal (hexadecimal) representation.
     This strips grouping information, removes surrounding whitespace and
@@ -83,12 +88,13 @@ def compact(number, strip_check_digit=True):
         cd = ''
     # convert to hex if needed
     if len(number) == 18:
-        number = '%08X%06X' % ( int(number[0:10]), int(number[10:18]) )
+        number = '%08X%06X' % (int(number[0:10]), int(number[10:18]))
         if cd:
             cd = _calc_check_digit(number)
     # put parts back together again
     return number + cd
 
+
 def is_valid(number):
     """Checks to see if the number provided is a valid MEID number."""
     from stdnum import luhn
@@ -107,6 +113,7 @@ def is_valid(number):
     # normal hex Luhn validation
     return not cd or luhn.is_valid(number + cd, alphabet=_hex_alphabet)
 
+
 def format(number, separator=' ', format=None, add_check_digit=False):
     """Reformat the passed number to the standard format. The separator
     used can be provided. If the format is specified (either 'hex' or
@@ -118,12 +125,12 @@ def format(number, separator=' ', format=None, add_check_digit=False):
     # format conversions if needed
     if format == 'dec' and len(number) == 14:
         # convert to decimal
-        number = '%010d%08d' % ( int(number[0:8], 16), int(number[8:14], 16) )
+        number = '%010d%08d' % (int(number[0:8], 16), int(number[8:14], 16))
         if cd:
             cd = _calc_check_digit(number)
     elif format == 'hex' and len(number) == 18:
         # convert to hex
-        number = '%08X%06X' % ( int(number[0:10]), int(number[10:18]) )
+        number = '%08X%06X' % (int(number[0:10]), int(number[10:18]))
         if cd:
             cd = _calc_check_digit(number)
     # see if we need to add a check digit
@@ -131,11 +138,13 @@ def format(number, separator=' ', format=None, add_check_digit=False):
         cd = _calc_check_digit(number)
     # split number according to format
     if len(number) == 14:
-        number = [ number[i*2:i*2+2] for i in range(7) ] + [ cd ]
+        number = [number[i * 2:i * 2 + 2]
+                  for i in range(7)] + [cd]
     else:
-        number = ( number[:5], number[5:10], number[10:14], number[14:], cd )
+        number = (number[:5], number[5:10], number[10:14], number[14:], cd)
     return separator.join(x for x in number if x)
 
+
 def to_pseudo_esn(number):
     """Convert the provided MEID to a pseudo ESN (pESN). The ESN is returned
     in compact HEX representation."""
@@ -144,4 +153,4 @@ def to_pseudo_esn(number):
     s = hashlib.sha1(compact(number, strip_check_digit=True).decode('hex'))
     # return the last 6 digits of the hash prefixed with the reserved
     # manufacturer code
-    return "80" + s.hexdigest()[-6:].upper()
+    return '80' + s.hexdigest()[-6:].upper()
